==> nodejs_interop-0.7.0.tar.gz: lib/src/npm/ipaddr.dart <==
part of nodejs_interop.npm;

/// The [`ipaddr.js`](https://www.npmjs.com/package/ipaddr.js) module.
@JS()
abstract class IPAddrModule {

  /// Takes a byte list and create an appropriate [IPv4] or [IPv6] object if the input satisfies the requirements.
  /// For [IPv4] it has to be a list of four 8-bit values, while for [IPv6] it has to be a list of sixteen 8-bit values.
  external IPAddress fromByteArray(List<int> bytes);

  /// Returns a value indicating whether the specified [address] is a valid IPv4 or IPv6 address.
  external bool isValid(String address);

  /// Parses the specified [address] into an [IPAddress] object.
  /// Throws an error if the address is not a valid internet address.
  external IPAddress parse(String address);

  /// Parses the specified [address] including a CIDR range into an [IPAddress] object.
  /// Throws an error if the address is not a valid internet address with a CIDR range.
  external List parseCIDR(String address);

  /// Parses the specified [address] into an [IPAddress] object, converting IPv4-Mapped IPv6 addresses to [IPv4] objects.
  /// Throws an error if the address is not a valid internet address.
  external IPAddress process(String address);

  /// Checks whether the specified [address] falls into a certain CIDR range.
  /// Returns the name of the CIDR range, or [defaultName] if the address does not fall into any range.
  external String subnetMatch(IPAddress address, rangeList, [String defaultName = 'unicast']);
}

/// An internet address.
@JS()
abstract class IPAddress {

  /// The type of IP protocol of this [IPAddress].
  external String kind();

  /// Checks whether this address falls into a certain CIDR [range].
  external bool match(range, [int bits]);

  /// Returns a CIDR prefix length for a valid IPv4 netmask or `null` if the netmask is invalid.
  external int prefixLengthFromSubnetMask();

  /// Returns one of predefined names for several special ranges defined by IP protocols.
  external String range();

  /// The raw address of this [IPAddress]. The result is either a 4 or 16 byte long list.
  external List<int> toByteArray();

  /// Returns a normalized string representation of this object.
  external String toNormalizedString();
}

/// Defines the type of IP protocol of an [IPAddress] object.
abstract class IPAddressKind {

  /// The address is an IPv4 one.
  static const String ipv4 = 'ipv4';

  /// The address is an IPv6 one.
  static const String ipv6 = 'ipv6';
}

/// An IPv4 address.
@JS(r'$ipaddr_js.IPv4')
class IPv4 extends IPAddress {

  /// Creates a new IPv4 address.
  external IPv4(List<int> octets);

  /// The underlying binary representation of this address.
  external List<int> get octets;

  /// Returns the broadcast address for a given IPv4 interface and netmask in CIDR notation.
  external static IPv4 broadcastAddressFromCIDR(String cidr);

  /// Returns a value indicating whether the specified [address] is a valid IPv4 address.
  external static bool isValid(String address);

  /// Checks whether the specified [address] is a valid IPv4 address and that it is written in four-part decimal format.
  external static bool isValidFourPartDecimal(String address);

  /// Returns the network address for a given IPv4 interface and netmask in CIDR notation.
  external static IPv4 networkAddressFromCIDR(String cidr);

  /// Parses the specified [address] into an [IPv4] object.
  /// Throws an error if the address is not a valid IPv4 address.
  external static IPv4 parse(String address);

  /// Parses the specified IPv4 [address] including a CIDR range into an [IPv4] object.
  /// Throws an error if the address is not a valid IPv4 address with a CIDR range.
  external static List parseCIDR(String address);

  /// Returns an IPv4 netmask for a valid CIDR prefix [length].
  external static IPv4 subnetMaskFromPrefixLength(int length);

  /// Converts this address to an IPv4-Mapped IPv6 address.
  external IPv6 toIPv4MappedAddress();
}

/// Defines the special IPv4 ranges.
abstract class IPv4Range {

  /// A broadcast address.
  static const String broadcast = 'broadcast';

  /// A Carrier-Grade NAT (CGN) address.
  static const String carrierGradeNat = 'carrierGradeNat';

  /// A link-local address.
  static const String linkLocal = 'linkLocal';

  /// A loopback address.
  static const String loopback = 'loopback';

  /// A multicast address.
  static const String multicast = 'multicast';

  /// A private address.
  static const String private = 'private';

  /// A reserved address.
  static const String reserved = 'reserved';

  /// An unspecified range.
  static const String unspecified = 'unspecified';
}

/// An IPv6 address.
@JS(r'$ipaddr_js.IPv6')
class IPv6 extends IPAddress {

  /// Creates a new IPv6 address.
  external IPv6(List<int> parts, [String zoneId]);

  /// The underlying binary representation of this address.
  external List<int> get parts;

  /// The IPv6 zone index of this address.
  external String get zoneId;

  /// Returns a value indicating whether this address is a IPv4-Mapped IPv6 address.
  external bool isIPv4MappedAddress();

  /// Returns a value indicating whether the specified [address] is a valid IPv6 address.
  external static bool isValid(String address);

  /// Parses the specified [address] into an [IPv6] object.
  /// Throws an error if the address is not a valid IPv6 address.
  external static IPv6 parse(String address);

  /// Parses the specified IPv6 [address] including a CIDR range into an [IPv6] object.
  /// Throws an error if the address is not a valid IPv6 address with a CIDR range.
  external static List parseCIDR(String address);

  /// Converts this IPv4-Mapped IPv6 address to an IPv4 one.
  external IPv4 toIPv4Address();
}

/// Defines the special IPv6 ranges.
abstract class IPv6Range {

  /// An IPv4 address mapped to an IPv6 one.
  static const String ipv4Mapped = 'ipv4Mapped';

  /// A link-local address.
  static const String linkLocal = 'linkLocal';

  /// A loopback address.
  static const String loopback = 'loopback';

  /// A multicast address.
  static const String multicast = 'multicast';

  /// A reserved address.
  static const String reserved = 'reserved';

  /// An IPv4 address translated to an IPv6 one.
  static const String rfc6052 = 'rfc6052';

  /// An IPv4 address translated to an IPv6 one using the Stateless IP/ICMP Translation Algorithm (SIIT).
  static const String rfc6145 = 'rfc6145';

  /// An IPv6 address constructed using a `6to4` prefix.
  static const String sixToFour = '6to4';

  /// An IPv4 address translated to an IPv6 one using stateful NAT64 translation.
  static const String teredo = 'teredo';

  /// A unique local address.
  static const String uniqueLocal = 'uniqueLocal';

  /// An unspecified range.
  static const String unspecified = 'unspecified';
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/npm/ipaddr.dart <==
/// Support for interoperating with [`ipaddr.js`](https://www.npmjs.com/package/ipaddr.js) package.
@JS()
library nodejs_interop.npm.ipaddr;

import 'package:js/js.dart';

/// An internet address.
@JS()
abstract class _IPAddress {

  /// The type of IP protocol of this [_IPAddress].
  external String kind();

  /// Checks whether this address falls into a certain CIDR [range].
  external bool match(range, [int bits]);

  /// Returns a CIDR prefix length for a valid IPv4 netmask or `null` if the netmask is invalid.
  external int prefixLengthFromSubnetMask();

  /// Returns one of predefined names for several special ranges defined by IP protocols.
  external String range();

  /// The raw address of this [_IPAddress]. The result is either a 4 or 16 byte long list.
  external List<int> toByteArray();

  /// Returns a normalized string representation of this object.
  external String toNormalizedString();
}

/// The [`ipaddr.js`](https://www.npmjs.com/package/ipaddr.js) module.
@JS()
abstract class IPAddrModule {

  /// Takes a byte list and create an appropriate [IPv4] or [IPv6] object if the input satisfies the requirements.
  /// For [IPv4] it has to be a list of four 8-bit values, while for [IPv6] it has to be a list of sixteen 8-bit values.
  external _IPAddress fromByteArray(List<int> bytes);

  /// Returns a value indicating whether the specified [address] is a valid IPv4 or IPv6 address.
  external bool isValid(String address);

  /// Parses the specified [address] into an [_IPAddress] object.
  /// Throws an error if the address is not a valid internet address.
  external _IPAddress parse(String address);

  /// Parses the specified [address] including a CIDR range into an [_IPAddress] object.
  /// Throws an error if the address is not a valid internet address with a CIDR range.
  external List parseCIDR(String address);

  /// Parses the specified [address] into an [_IPAddress] object, converting IPv4-Mapped IPv6 addresses to [IPv4] objects.
  /// Throws an error if the address is not a valid internet address.
  external _IPAddress process(String address);

  /// Checks whether the specified [address] falls into a certain CIDR range.
  /// Returns the name of the CIDR range, or [defaultName] if the address does not fall into any range.
  external String subnetMatch(_IPAddress address, rangeList, [String defaultName = 'unicast']);
}

/// Defines the type of IP protocol of an [_IPAddress] object.
abstract class IPKind {

  /// The address is an IPv4 one.
  static const String ipv4 = 'ipv4';

  /// The address is an IPv6 one.
  static const String ipv6 = 'ipv6';
}

/// An IPv4 address.
@JS(r'$ipaddr_js.IPv4')
class IPv4 extends _IPAddress {

  /// Creates a new IPv4 address.
  external IPv4(List<int> octets);

  /// The underlying binary representation of this address.
  external List<int> get octets;

  /// Returns the broadcast address for a given IPv4 interface and netmask in CIDR notation.
  external static IPv4 broadcastAddressFromCIDR(String cidr);

  /// Returns a value indicating whether the specified [address] is a valid IPv4 address.
  external static bool isValid(String address);

  /// Checks whether the specified [address] is a valid IPv4 address and that it is written in four-part decimal format.
  external static bool isValidFourPartDecimal(String address);

  /// Returns the network address for a given IPv4 interface and netmask in CIDR notation.
  external static IPv4 networkAddressFromCIDR(String cidr);

  /// Parses the specified [address] into an [IPv4] object.
  /// Throws an error if the address is not a valid IPv4 address.
  external static IPv4 parse(String address);

  /// Parses the specified IPv4 [address] including a CIDR range into an [IPv4] object.
  /// Throws an error if the address is not a valid IPv4 address with a CIDR range.
  external static List parseCIDR(String address);

  /// Returns an IPv4 netmask for a valid CIDR prefix [length].
  external static IPv4 subnetMaskFromPrefixLength(int length);

  /// Converts this address to an IPv4-Mapped IPv6 address.
  external IPv6 toIPv4MappedAddress();
}

/// Defines the special IPv4 ranges.
abstract class IPv4Range {

  /// A broadcast address.
  static const String broadcast = 'broadcast';

  /// A Carrier-Grade NAT (CGN) address.
  static const String carrierGradeNat = 'carrierGradeNat';

  /// A link-local address.
  static const String linkLocal = 'linkLocal';

  /// A loopback address.
  static const String loopback = 'loopback';

  /// A multicast address.
  static const String multicast = 'multicast';

  /// A private address.
  static const String private = 'private';

  /// A reserved address.
  static const String reserved = 'reserved';

  /// An unspecified range.
  static const String unspecified = 'unspecified';
}

/// An IPv6 address.
@JS(r'$ipaddr_js.IPv6')
class IPv6 extends _IPAddress {

  /// Creates a new IPv6 address.
  external IPv6(List<int> parts, [String zoneId]);

  /// The underlying binary representation of this address.
  external List<int> get parts;

  /// The IPv6 zone index of this address.
  external String get zoneId;

  /// Returns a value indicating whether this address is a IPv4-Mapped IPv6 address.
  external bool isIPv4MappedAddress();

  /// Returns a value indicating whether the specified [address] is a valid IPv6 address.
  external static bool isValid(String address);

  /// Parses the specified [address] into an [IPv6] object.
  /// Throws an error if the address is not a valid IPv6 address.
  external static IPv6 parse(String address);

  /// Parses the specified IPv6 [address] including a CIDR range into an [IPv6] object.
  /// Throws an error if the address is not a valid IPv6 address with a CIDR range.
  external static List parseCIDR(String address);

  /// Converts this IPv4-Mapped IPv6 address to an IPv4 one.
  external IPv4 toIPv4Address();
}

/// Defines the special IPv6 ranges.
abstract class IPv6Range {

  /// An IPv4 address mapped to an IPv6 one.
  static const String ipv4Mapped = 'ipv4Mapped';

  /// A link-local address.
  static const String linkLocal = 'linkLocal';

  /// A loopback address.
  static const String loopback = 'loopback';

  /// A multicast address.
  static const String multicast = 'multicast';

  /// A reserved address.
  static const String reserved = 'reserved';

  /// An IPv4 address translated to an IPv6 one.
  static const String rfc6052 = 'rfc6052';

  /// An IPv4 address translated to an IPv6 one using the Stateless IP/ICMP Translation Algorithm (SIIT).
  static const String rfc6145 = 'rfc6145';

  /// An IPv6 address constructed using a `6to4` prefix.
  static const String sixToFour = '6to4';

  /// An IPv4 address translated to an IPv6 one using stateful NAT64 translation.
  static const String teredo = 'teredo';

  /// A unique local address.
  static const String uniqueLocal = 'uniqueLocal';

  /// An unspecified range.
  static const String unspecified = 'unspecified';
}
